@@ -4,6 +4,9 @@
 # Date:    16-Jul-2019
 # Version: 0.001 Initial version
 #
+# Updates:
+#   29-Mar-2023 dwp Correct attribute name '_rcsb_chem_comp_target.provenance_code' to '_rcsb_chem_comp_target.provenance_source'
+#    5-Apr-2023 dwp Stop loading rcsb_chem_comp_synonyms for rcsb_chem_comp_synonyms.type 'Brand Name' (to be loaded to new separate data item later)
 ##
 """
 Helper class implements external method references supporting chemical
@@ -470,7 +473,7 @@ class DictMethodChemRefHelper(object):
              _rcsb_chem_comp_target.organism_common_name
              _rcsb_chem_comp_target.reference_database_name
              _rcsb_chem_comp_target.reference_database_accession_code
-             _rcsb_chem_comp_target.provenance_code
+             _rcsb_chem_comp_target.provenance_source
              ATP 1 "O-phosphoseryl-tRNA(Sec) selenium transferase" target cofactor Human UniProt Q9HD40 DrugBank
 
         DrugBank target info:
@@ -518,13 +521,13 @@ class DictMethodChemRefHelper(object):
                                 "organism_common_name",
                                 "reference_database_name",
                                 "reference_database_accession_code",
-                                "provenance_code",
+                                "provenance_source",
                             ],
                         )
                     )
                 wObj = dataContainer.getObj(catName)
                 logger.debug("Using DrugBank mapping length %d", len(dbMapD))
-                rL = wObj.selectIndices("DrugBank", "provenance_code")
+                rL = wObj.selectIndices("DrugBank", "provenance_source")
                 if rL:
                     ok = wObj.removeRows(rL)
                     if not ok:
@@ -544,7 +547,7 @@ class DictMethodChemRefHelper(object):
                     if "uniprot_ids" in tD:
                         wObj.setValue("UniProt", "reference_database_name", iRow)
                         wObj.setValue(tD["uniprot_ids"], "reference_database_accession_code", iRow)
-                    wObj.setValue("DrugBank", "provenance_code", iRow)
+                    wObj.setValue("DrugBank", "provenance_source", iRow)
                     iRow += 1
 
             #
@@ -947,15 +950,15 @@ class DictMethodChemRefHelper(object):
                             wObj.setValue("DrugBank", "provenance_source", iRow)
                             wObj.setValue("Synonym", "type", iRow)
                             iRow += 1
-                    if "brand_names" in dbMapD[ccId]:
-                        iRow = wObj.getRowCount()
-                        for nm in dbMapD[ccId]["brand_names"]:
-                            wObj.setValue(ccId, "comp_id", iRow)
-                            wObj.setValue(str(nm).strip(), "name", iRow)
-                            wObj.setValue(iRow + 1, "ordinal", iRow)
-                            wObj.setValue("DrugBank", "provenance_source", iRow)
-                            wObj.setValue("Brand Name", "type", iRow)
-                            iRow += 1
+                    # if "brand_names" in dbMapD[ccId]:
+                    #     iRow = wObj.getRowCount()
+                    #     for nm in dbMapD[ccId]["brand_names"]:
+                    #         wObj.setValue(ccId, "comp_id", iRow)
+                    #         wObj.setValue(str(nm).strip(), "name", iRow)
+                    #         wObj.setValue(iRow + 1, "ordinal", iRow)
+                    #         wObj.setValue("DrugBank", "provenance_source", iRow)
+                    #         wObj.setValue("Brand Name", "type", iRow)
+                    #         iRow += 1
 
             return True
         except Exception as e:
